# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetManagedDatabaseSqlTuningSetsResult',
    'AwaitableGetManagedDatabaseSqlTuningSetsResult',
    'get_managed_database_sql_tuning_sets',
    'get_managed_database_sql_tuning_sets_output',
]

@pulumi.output_type
class GetManagedDatabaseSqlTuningSetsResult:
    """
    A collection of values returned by getManagedDatabaseSqlTuningSets.
    """
    def __init__(__self__, filters=None, id=None, managed_database_id=None, name_contains=None, owner=None, sql_tuning_set_collections=None):
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if managed_database_id and not isinstance(managed_database_id, str):
            raise TypeError("Expected argument 'managed_database_id' to be a str")
        pulumi.set(__self__, "managed_database_id", managed_database_id)
        if name_contains and not isinstance(name_contains, str):
            raise TypeError("Expected argument 'name_contains' to be a str")
        pulumi.set(__self__, "name_contains", name_contains)
        if owner and not isinstance(owner, str):
            raise TypeError("Expected argument 'owner' to be a str")
        pulumi.set(__self__, "owner", owner)
        if sql_tuning_set_collections and not isinstance(sql_tuning_set_collections, list):
            raise TypeError("Expected argument 'sql_tuning_set_collections' to be a list")
        pulumi.set(__self__, "sql_tuning_set_collections", sql_tuning_set_collections)

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetManagedDatabaseSqlTuningSetsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="managedDatabaseId")
    def managed_database_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Managed Database.
        """
        return pulumi.get(self, "managed_database_id")

    @property
    @pulumi.getter(name="nameContains")
    def name_contains(self) -> Optional[str]:
        return pulumi.get(self, "name_contains")

    @property
    @pulumi.getter
    def owner(self) -> Optional[str]:
        """
        The owner of the SQL tuning set.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter(name="sqlTuningSetCollections")
    def sql_tuning_set_collections(self) -> Sequence['outputs.GetManagedDatabaseSqlTuningSetsSqlTuningSetCollectionResult']:
        """
        The list of sql_tuning_set_collection.
        """
        return pulumi.get(self, "sql_tuning_set_collections")


class AwaitableGetManagedDatabaseSqlTuningSetsResult(GetManagedDatabaseSqlTuningSetsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetManagedDatabaseSqlTuningSetsResult(
            filters=self.filters,
            id=self.id,
            managed_database_id=self.managed_database_id,
            name_contains=self.name_contains,
            owner=self.owner,
            sql_tuning_set_collections=self.sql_tuning_set_collections)


def get_managed_database_sql_tuning_sets(filters: Optional[Sequence[pulumi.InputType['GetManagedDatabaseSqlTuningSetsFilterArgs']]] = None,
                                         managed_database_id: Optional[str] = None,
                                         name_contains: Optional[str] = None,
                                         owner: Optional[str] = None,
                                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetManagedDatabaseSqlTuningSetsResult:
    """
    This data source provides the list of Managed Database Sql Tuning Sets in Oracle Cloud Infrastructure Database Management service.

    Lists the SQL tuning sets for the specified Managed Database.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_managed_database_sql_tuning_sets = oci.DatabaseManagement.get_managed_database_sql_tuning_sets(managed_database_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        name_contains=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        owner=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str managed_database_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Managed Database.
    :param str name_contains: Allow searching the name of the SQL tuning set by partial matching. The search is case insensitive.
    :param str owner: The owner of the SQL tuning set.
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['managedDatabaseId'] = managed_database_id
    __args__['nameContains'] = name_contains
    __args__['owner'] = owner
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:DatabaseManagement/getManagedDatabaseSqlTuningSets:getManagedDatabaseSqlTuningSets', __args__, opts=opts, typ=GetManagedDatabaseSqlTuningSetsResult).value

    return AwaitableGetManagedDatabaseSqlTuningSetsResult(
        filters=__ret__.filters,
        id=__ret__.id,
        managed_database_id=__ret__.managed_database_id,
        name_contains=__ret__.name_contains,
        owner=__ret__.owner,
        sql_tuning_set_collections=__ret__.sql_tuning_set_collections)


@_utilities.lift_output_func(get_managed_database_sql_tuning_sets)
def get_managed_database_sql_tuning_sets_output(filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetManagedDatabaseSqlTuningSetsFilterArgs']]]]] = None,
                                                managed_database_id: Optional[pulumi.Input[str]] = None,
                                                name_contains: Optional[pulumi.Input[Optional[str]]] = None,
                                                owner: Optional[pulumi.Input[Optional[str]]] = None,
                                                opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetManagedDatabaseSqlTuningSetsResult]:
    """
    This data source provides the list of Managed Database Sql Tuning Sets in Oracle Cloud Infrastructure Database Management service.

    Lists the SQL tuning sets for the specified Managed Database.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_managed_database_sql_tuning_sets = oci.DatabaseManagement.get_managed_database_sql_tuning_sets(managed_database_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        name_contains=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        owner=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str managed_database_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Managed Database.
    :param str name_contains: Allow searching the name of the SQL tuning set by partial matching. The search is case insensitive.
    :param str owner: The owner of the SQL tuning set.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetMigrationAssetResult',
    'AwaitableGetMigrationAssetResult',
    'get_migration_asset',
    'get_migration_asset_output',
]

@pulumi.output_type
class GetMigrationAssetResult:
    """
    A collection of values returned by getMigrationAsset.
    """
    def __init__(__self__, availability_domain=None, compartment_id=None, depended_on_bies=None, display_name=None, id=None, inventory_asset_id=None, lifecycle_details=None, migration_asset_depends_ons=None, migration_asset_id=None, migration_id=None, notifications=None, parent_snapshot=None, replication_compartment_id=None, replication_schedule_id=None, snap_shot_bucket_name=None, snapshots=None, source_asset_id=None, state=None, tenancy_id=None, time_created=None, time_updated=None, type=None):
        if availability_domain and not isinstance(availability_domain, str):
            raise TypeError("Expected argument 'availability_domain' to be a str")
        pulumi.set(__self__, "availability_domain", availability_domain)
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if depended_on_bies and not isinstance(depended_on_bies, list):
            raise TypeError("Expected argument 'depended_on_bies' to be a list")
        pulumi.set(__self__, "depended_on_bies", depended_on_bies)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if inventory_asset_id and not isinstance(inventory_asset_id, str):
            raise TypeError("Expected argument 'inventory_asset_id' to be a str")
        pulumi.set(__self__, "inventory_asset_id", inventory_asset_id)
        if lifecycle_details and not isinstance(lifecycle_details, str):
            raise TypeError("Expected argument 'lifecycle_details' to be a str")
        pulumi.set(__self__, "lifecycle_details", lifecycle_details)
        if migration_asset_depends_ons and not isinstance(migration_asset_depends_ons, list):
            raise TypeError("Expected argument 'migration_asset_depends_ons' to be a list")
        pulumi.set(__self__, "migration_asset_depends_ons", migration_asset_depends_ons)
        if migration_asset_id and not isinstance(migration_asset_id, str):
            raise TypeError("Expected argument 'migration_asset_id' to be a str")
        pulumi.set(__self__, "migration_asset_id", migration_asset_id)
        if migration_id and not isinstance(migration_id, str):
            raise TypeError("Expected argument 'migration_id' to be a str")
        pulumi.set(__self__, "migration_id", migration_id)
        if notifications and not isinstance(notifications, list):
            raise TypeError("Expected argument 'notifications' to be a list")
        pulumi.set(__self__, "notifications", notifications)
        if parent_snapshot and not isinstance(parent_snapshot, str):
            raise TypeError("Expected argument 'parent_snapshot' to be a str")
        pulumi.set(__self__, "parent_snapshot", parent_snapshot)
        if replication_compartment_id and not isinstance(replication_compartment_id, str):
            raise TypeError("Expected argument 'replication_compartment_id' to be a str")
        pulumi.set(__self__, "replication_compartment_id", replication_compartment_id)
        if replication_schedule_id and not isinstance(replication_schedule_id, str):
            raise TypeError("Expected argument 'replication_schedule_id' to be a str")
        pulumi.set(__self__, "replication_schedule_id", replication_schedule_id)
        if snap_shot_bucket_name and not isinstance(snap_shot_bucket_name, str):
            raise TypeError("Expected argument 'snap_shot_bucket_name' to be a str")
        pulumi.set(__self__, "snap_shot_bucket_name", snap_shot_bucket_name)
        if snapshots and not isinstance(snapshots, dict):
            raise TypeError("Expected argument 'snapshots' to be a dict")
        pulumi.set(__self__, "snapshots", snapshots)
        if source_asset_id and not isinstance(source_asset_id, str):
            raise TypeError("Expected argument 'source_asset_id' to be a str")
        pulumi.set(__self__, "source_asset_id", source_asset_id)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if tenancy_id and not isinstance(tenancy_id, str):
            raise TypeError("Expected argument 'tenancy_id' to be a str")
        pulumi.set(__self__, "tenancy_id", tenancy_id)
        if time_created and not isinstance(time_created, str):
            raise TypeError("Expected argument 'time_created' to be a str")
        pulumi.set(__self__, "time_created", time_created)
        if time_updated and not isinstance(time_updated, str):
            raise TypeError("Expected argument 'time_updated' to be a str")
        pulumi.set(__self__, "time_updated", time_updated)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="availabilityDomain")
    def availability_domain(self) -> str:
        """
        Availability domain
        """
        return pulumi.get(self, "availability_domain")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        Compartment Identifier
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="dependedOnBies")
    def depended_on_bies(self) -> Sequence[str]:
        """
        List of migration assets that depend on the asset.
        """
        return pulumi.get(self, "depended_on_bies")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        Asset ID generated by mirgration service. It is used in the mirgration service pipeline.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="inventoryAssetId")
    def inventory_asset_id(self) -> str:
        return pulumi.get(self, "inventory_asset_id")

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> str:
        """
        A message describing the current state in more detail. For example, it can be used to provide actionable information for a resource in Failed state.
        """
        return pulumi.get(self, "lifecycle_details")

    @property
    @pulumi.getter(name="migrationAssetDependsOns")
    def migration_asset_depends_ons(self) -> Sequence[str]:
        return pulumi.get(self, "migration_asset_depends_ons")

    @property
    @pulumi.getter(name="migrationAssetId")
    def migration_asset_id(self) -> str:
        return pulumi.get(self, "migration_asset_id")

    @property
    @pulumi.getter(name="migrationId")
    def migration_id(self) -> str:
        """
        OCID of the associated migration.
        """
        return pulumi.get(self, "migration_id")

    @property
    @pulumi.getter
    def notifications(self) -> Sequence[str]:
        """
        List of notifications
        """
        return pulumi.get(self, "notifications")

    @property
    @pulumi.getter(name="parentSnapshot")
    def parent_snapshot(self) -> str:
        """
        The parent snapshot of the migration asset to be used by the replication task.
        """
        return pulumi.get(self, "parent_snapshot")

    @property
    @pulumi.getter(name="replicationCompartmentId")
    def replication_compartment_id(self) -> str:
        """
        Replication compartment identifier
        """
        return pulumi.get(self, "replication_compartment_id")

    @property
    @pulumi.getter(name="replicationScheduleId")
    def replication_schedule_id(self) -> str:
        """
        Replication schedule identifier
        """
        return pulumi.get(self, "replication_schedule_id")

    @property
    @pulumi.getter(name="snapShotBucketName")
    def snap_shot_bucket_name(self) -> str:
        """
        Name of snapshot bucket
        """
        return pulumi.get(self, "snap_shot_bucket_name")

    @property
    @pulumi.getter
    def snapshots(self) -> Mapping[str, Any]:
        """
        Key-value pair representing disks ID mapped to the OCIDs of replicated or hydration server volume snapshots. Example: `{"bar-key": "value"}`
        """
        return pulumi.get(self, "snapshots")

    @property
    @pulumi.getter(name="sourceAssetId")
    def source_asset_id(self) -> str:
        """
        OCID that is referenced to an asset for an inventory.
        """
        return pulumi.get(self, "source_asset_id")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The current state of the migration asset.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="tenancyId")
    def tenancy_id(self) -> str:
        """
        Tenancy identifier
        """
        return pulumi.get(self, "tenancy_id")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        The time when the migration asset was created. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> str:
        """
        The time when the migration asset was updated. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_updated")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The type of asset referenced for inventory.
        """
        return pulumi.get(self, "type")


class AwaitableGetMigrationAssetResult(GetMigrationAssetResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetMigrationAssetResult(
            availability_domain=self.availability_domain,
            compartment_id=self.compartment_id,
            depended_on_bies=self.depended_on_bies,
            display_name=self.display_name,
            id=self.id,
            inventory_asset_id=self.inventory_asset_id,
            lifecycle_details=self.lifecycle_details,
            migration_asset_depends_ons=self.migration_asset_depends_ons,
            migration_asset_id=self.migration_asset_id,
            migration_id=self.migration_id,
            notifications=self.notifications,
            parent_snapshot=self.parent_snapshot,
            replication_compartment_id=self.replication_compartment_id,
            replication_schedule_id=self.replication_schedule_id,
            snap_shot_bucket_name=self.snap_shot_bucket_name,
            snapshots=self.snapshots,
            source_asset_id=self.source_asset_id,
            state=self.state,
            tenancy_id=self.tenancy_id,
            time_created=self.time_created,
            time_updated=self.time_updated,
            type=self.type)


def get_migration_asset(migration_asset_id: Optional[str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetMigrationAssetResult:
    """
    This data source provides details about a specific Migration Asset resource in Oracle Cloud Infrastructure Cloud Migrations service.

    Gets a migration asset by identifier.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_migration_asset = oci.CloudMigrations.get_migration_asset(migration_asset_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str migration_asset_id: Unique migration asset identifier
    """
    __args__ = dict()
    __args__['migrationAssetId'] = migration_asset_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:CloudMigrations/getMigrationAsset:getMigrationAsset', __args__, opts=opts, typ=GetMigrationAssetResult).value

    return AwaitableGetMigrationAssetResult(
        availability_domain=__ret__.availability_domain,
        compartment_id=__ret__.compartment_id,
        depended_on_bies=__ret__.depended_on_bies,
        display_name=__ret__.display_name,
        id=__ret__.id,
        inventory_asset_id=__ret__.inventory_asset_id,
        lifecycle_details=__ret__.lifecycle_details,
        migration_asset_depends_ons=__ret__.migration_asset_depends_ons,
        migration_asset_id=__ret__.migration_asset_id,
        migration_id=__ret__.migration_id,
        notifications=__ret__.notifications,
        parent_snapshot=__ret__.parent_snapshot,
        replication_compartment_id=__ret__.replication_compartment_id,
        replication_schedule_id=__ret__.replication_schedule_id,
        snap_shot_bucket_name=__ret__.snap_shot_bucket_name,
        snapshots=__ret__.snapshots,
        source_asset_id=__ret__.source_asset_id,
        state=__ret__.state,
        tenancy_id=__ret__.tenancy_id,
        time_created=__ret__.time_created,
        time_updated=__ret__.time_updated,
        type=__ret__.type)


@_utilities.lift_output_func(get_migration_asset)
def get_migration_asset_output(migration_asset_id: Optional[pulumi.Input[str]] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetMigrationAssetResult]:
    """
    This data source provides details about a specific Migration Asset resource in Oracle Cloud Infrastructure Cloud Migrations service.

    Gets a migration asset by identifier.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_migration_asset = oci.CloudMigrations.get_migration_asset(migration_asset_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str migration_asset_id: Unique migration asset identifier
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetAppCatalogListingsResult',
    'AwaitableGetAppCatalogListingsResult',
    'get_app_catalog_listings',
    'get_app_catalog_listings_output',
]

@pulumi.output_type
class GetAppCatalogListingsResult:
    """
    A collection of values returned by getAppCatalogListings.
    """
    def __init__(__self__, app_catalog_listings=None, display_name=None, filters=None, id=None, publisher_name=None, publisher_type=None):
        if app_catalog_listings and not isinstance(app_catalog_listings, list):
            raise TypeError("Expected argument 'app_catalog_listings' to be a list")
        pulumi.set(__self__, "app_catalog_listings", app_catalog_listings)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if publisher_name and not isinstance(publisher_name, str):
            raise TypeError("Expected argument 'publisher_name' to be a str")
        pulumi.set(__self__, "publisher_name", publisher_name)
        if publisher_type and not isinstance(publisher_type, str):
            raise TypeError("Expected argument 'publisher_type' to be a str")
        pulumi.set(__self__, "publisher_type", publisher_type)

    @property
    @pulumi.getter(name="appCatalogListings")
    def app_catalog_listings(self) -> Sequence['outputs.GetAppCatalogListingsAppCatalogListingResult']:
        """
        The list of app_catalog_listings.
        """
        return pulumi.get(self, "app_catalog_listings")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[str]:
        """
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetAppCatalogListingsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="publisherName")
    def publisher_name(self) -> Optional[str]:
        """
        The name of the publisher who published this listing.
        """
        return pulumi.get(self, "publisher_name")

    @property
    @pulumi.getter(name="publisherType")
    def publisher_type(self) -> Optional[str]:
        return pulumi.get(self, "publisher_type")


class AwaitableGetAppCatalogListingsResult(GetAppCatalogListingsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAppCatalogListingsResult(
            app_catalog_listings=self.app_catalog_listings,
            display_name=self.display_name,
            filters=self.filters,
            id=self.id,
            publisher_name=self.publisher_name,
            publisher_type=self.publisher_type)


def get_app_catalog_listings(display_name: Optional[str] = None,
                             filters: Optional[Sequence[pulumi.InputType['GetAppCatalogListingsFilterArgs']]] = None,
                             publisher_name: Optional[str] = None,
                             publisher_type: Optional[str] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAppCatalogListingsResult:
    """
    This data source provides the list of App Catalog Listings in Oracle Cloud Infrastructure Core service.

    Lists the published listings.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_app_catalog_listings = oci.Core.get_app_catalog_listings(display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        publisher_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        publisher_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str display_name: A filter to return only resources that match the given display name exactly.
    :param str publisher_name: A filter to return only the publisher that matches the given publisher name exactly.
    :param str publisher_type: A filter to return only publishers that match the given publisher type exactly. Valid types are OCI, ORACLE, TRUSTED, STANDARD.
    """
    __args__ = dict()
    __args__['displayName'] = display_name
    __args__['filters'] = filters
    __args__['publisherName'] = publisher_name
    __args__['publisherType'] = publisher_type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Core/getAppCatalogListings:getAppCatalogListings', __args__, opts=opts, typ=GetAppCatalogListingsResult).value

    return AwaitableGetAppCatalogListingsResult(
        app_catalog_listings=__ret__.app_catalog_listings,
        display_name=__ret__.display_name,
        filters=__ret__.filters,
        id=__ret__.id,
        publisher_name=__ret__.publisher_name,
        publisher_type=__ret__.publisher_type)


@_utilities.lift_output_func(get_app_catalog_listings)
def get_app_catalog_listings_output(display_name: Optional[pulumi.Input[Optional[str]]] = None,
                                    filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetAppCatalogListingsFilterArgs']]]]] = None,
                                    publisher_name: Optional[pulumi.Input[Optional[str]]] = None,
                                    publisher_type: Optional[pulumi.Input[Optional[str]]] = None,
                                    opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetAppCatalogListingsResult]:
    """
    This data source provides the list of App Catalog Listings in Oracle Cloud Infrastructure Core service.

    Lists the published listings.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_app_catalog_listings = oci.Core.get_app_catalog_listings(display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        publisher_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        publisher_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str display_name: A filter to return only resources that match the given display name exactly.
    :param str publisher_name: A filter to return only the publisher that matches the given publisher name exactly.
    :param str publisher_type: A filter to return only publishers that match the given publisher type exactly. Valid types are OCI, ORACLE, TRUSTED, STANDARD.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetAutonomousDbVersionsResult',
    'AwaitableGetAutonomousDbVersionsResult',
    'get_autonomous_db_versions',
    'get_autonomous_db_versions_output',
]

@pulumi.output_type
class GetAutonomousDbVersionsResult:
    """
    A collection of values returned by getAutonomousDbVersions.
    """
    def __init__(__self__, autonomous_db_versions=None, compartment_id=None, db_workload=None, filters=None, id=None):
        if autonomous_db_versions and not isinstance(autonomous_db_versions, list):
            raise TypeError("Expected argument 'autonomous_db_versions' to be a list")
        pulumi.set(__self__, "autonomous_db_versions", autonomous_db_versions)
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if db_workload and not isinstance(db_workload, str):
            raise TypeError("Expected argument 'db_workload' to be a str")
        pulumi.set(__self__, "db_workload", db_workload)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter(name="autonomousDbVersions")
    def autonomous_db_versions(self) -> Sequence['outputs.GetAutonomousDbVersionsAutonomousDbVersionResult']:
        """
        The list of autonomous_db_versions.
        """
        return pulumi.get(self, "autonomous_db_versions")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="dbWorkload")
    def db_workload(self) -> Optional[str]:
        """
        The Autonomous Database workload type. The following values are valid:
        * OLTP - indicates an Autonomous Transaction Processing database
        * DW - indicates an Autonomous Data Warehouse database
        * AJD - indicates an Autonomous JSON Database
        * APEX - indicates an Autonomous Database with the Oracle APEX Application Development workload type.
        """
        return pulumi.get(self, "db_workload")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetAutonomousDbVersionsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")


class AwaitableGetAutonomousDbVersionsResult(GetAutonomousDbVersionsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAutonomousDbVersionsResult(
            autonomous_db_versions=self.autonomous_db_versions,
            compartment_id=self.compartment_id,
            db_workload=self.db_workload,
            filters=self.filters,
            id=self.id)


def get_autonomous_db_versions(compartment_id: Optional[str] = None,
                               db_workload: Optional[str] = None,
                               filters: Optional[Sequence[pulumi.InputType['GetAutonomousDbVersionsFilterArgs']]] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAutonomousDbVersionsResult:
    """
    This data source provides the list of Autonomous Db Versions in Oracle Cloud Infrastructure Database service.

    Gets a list of supported Autonomous Database versions.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_autonomous_db_versions = oci.Database.get_autonomous_db_versions(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        db_workload=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The compartment [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param str db_workload: A filter to return only autonomous database resources that match the specified workload type.
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['dbWorkload'] = db_workload
    __args__['filters'] = filters
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Database/getAutonomousDbVersions:getAutonomousDbVersions', __args__, opts=opts, typ=GetAutonomousDbVersionsResult).value

    return AwaitableGetAutonomousDbVersionsResult(
        autonomous_db_versions=__ret__.autonomous_db_versions,
        compartment_id=__ret__.compartment_id,
        db_workload=__ret__.db_workload,
        filters=__ret__.filters,
        id=__ret__.id)


@_utilities.lift_output_func(get_autonomous_db_versions)
def get_autonomous_db_versions_output(compartment_id: Optional[pulumi.Input[str]] = None,
                                      db_workload: Optional[pulumi.Input[Optional[str]]] = None,
                                      filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetAutonomousDbVersionsFilterArgs']]]]] = None,
                                      opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetAutonomousDbVersionsResult]:
    """
    This data source provides the list of Autonomous Db Versions in Oracle Cloud Infrastructure Database service.

    Gets a list of supported Autonomous Database versions.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_autonomous_db_versions = oci.Database.get_autonomous_db_versions(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        db_workload=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The compartment [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param str db_workload: A filter to return only autonomous database resources that match the specified workload type.
    """
    ...
